@@ -23,7 +23,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #ifndef KCMDF_H
 #define KCMDF_H
 
-#include <kcmodule.h>
+#include <KCModule>
 
 #include "kdfwidget.h"
 #include "kdfconfig.h"
